@@ -1,4 +1,3 @@
-from __future__ import absolute_import
 import logging
 from logging.config import dictConfig
 
@@ -17,11 +16,6 @@ BROKER_URL = 'redis://'
 ECOMMERCE_API_ROOT = 'http://localhost:18130/api/v2/'
 # END ORDER FULFILLMENT
 
-# AUTHENTICATION
-JWT_SECRET_KEY = 'insecure-secret-key'
-JWT_ISSUER = 'ecommerce_worker'
-# END AUTHENTICATION
-
 # LOGGING
 logger_config = get_logger_config(debug=True, dev_env=True, local_loglevel='DEBUG')
 dictConfig(logger_config)
