@@ -1,15 +1,16 @@
 """Order fulfillment tasks."""
-from __future__ import absolute_import
 from ssl import SSLError
+from urllib.parse import urljoin
 
+import requests
 from celery import shared_task
 from celery.exceptions import Ignore
 from celery.utils.log import get_task_logger
-from edx_rest_api_client import exceptions
+from requests.exceptions import HTTPError, Timeout
 
-from ecommerce_worker.utils import get_configuration, get_ecommerce_client
+from ecommerce_worker.utils import get_configuration, get_access_token
 
-logger = get_task_logger(__name__)  # pylint: disable=invalid-name
+logger = get_task_logger(__name__)
 
 
 def _retry_order(self, exception, max_fulfillment_retries, order_number):
@@ -30,7 +31,8 @@ def _retry_order(self, exception, max_fulfillment_retries, order_number):
 
 @shared_task(bind=True, ignore_result=True)
 def fulfill_order(self, order_number, site_code=None, email_opt_in=False):
-    """Fulfills an order.
+    """
+    Fulfills an order.
 
     Arguments:
         order_number (str): Order number indicating which order to fulfill.
@@ -38,25 +40,37 @@ def fulfill_order(self, order_number, site_code=None, email_opt_in=False):
     Returns:
         None
     """
+
+    api_url = urljoin(
+        get_configuration('ECOMMERCE_API_ROOT', site_code=site_code) + '/',
+        f'orders/{order_number}/fulfill/'
+    )
     max_fulfillment_retries = get_configuration('MAX_FULFILLMENT_RETRIES', site_code=site_code)
-    api = get_ecommerce_client(site_code=site_code)
     try:
         logger.info('Requesting fulfillment of order [%s].', order_number)
-        api.orders(order_number).fulfill.put(email_opt_in=email_opt_in)
-    except exceptions.HttpClientError as exc:
-        status_code = exc.response.status_code  # pylint: disable=no-member
+        headers = {'Authorization': f'JWT {get_access_token()}'}
+        params = {'email_opt_in': email_opt_in}
+        response = requests.put(
+            api_url,
+            params=params,
+            headers=headers
+        )
+        response.raise_for_status()
+
+    except HTTPError as exc:
+        status_code = exc.response.status_code
         if status_code == 406:
             # The order is not fulfillable. Therefore, it must be complete.
             logger.info('Order [%s] has already been fulfilled. Ignoring.', order_number)
-            raise Ignore()
-        # Unknown client error. Let's retry to resolve it.
+            raise Ignore() from exc
+
+        # Unknown connection error while fulfills an order. Let's retry to resolve it.
         logger.warning(
-            'Fulfillment of order [%s] failed because of HttpClientError. Retrying',
+            'Fulfillment of order [%s] failed because of HTTPError. Retrying',
             order_number,
             exc_info=True
         )
         _retry_order(self, exc, max_fulfillment_retries, order_number)
-
-    except (exceptions.HttpServerError, exceptions.Timeout, SSLError) as exc:
+    except (Timeout, SSLError) as exc:
         # Fulfillment failed, retry
         _retry_order(self, exc, max_fulfillment_retries, order_number)
